==> ssp-center-api-0.1.26-gy4-20171013.084609-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqAppStatistics.java <==
/**
 * Project Name:media-manager-biz<br>
 * File Name:ReqAppStatistics.java<br>
 * Package Name:cn.com.duiba.tuia.media.manager.model.req<br>
 * Date:2016年12月21日上午10:53:48<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.util.List;

import org.apache.commons.lang3.builder.ToStringBuilder;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * ClassName: ReqAppStatistics <br/>
 * Function: 媒体数据请求对象. <br/>
 * date: 2016年12月21日 上午10:53:48 <br/>
 *
 * @author xiawei
 * @version
 * @since JDK 1.6
 */
@ApiModel
public class ReqAppStatistics extends ReqDateQuery {

    /**序列号*/
    private static final long serialVersionUID = 2154402586515939055L;

    /** 媒体ID. */
    @ApiModelProperty(value = "媒体ID", required = false)
    private Long       appId;

    /** 媒体名称. */
    @ApiModelProperty(value = "媒体名称", required = false)
    private String     appName;

    /** 系统平台. */
    @ApiModelProperty(value = "系统平台", required = false)
    private String     platform;
    
    /** 导出方式. */
    @ApiModelProperty(value = "导出方式", required = false)
    private Integer     exportType;//0是汇总，1是分日导出

    /** 用户ID. */
    @ApiModelProperty(value = "用户ID", required = false)
    private Long     mediaId;

    /** 用户邮箱. */
    @ApiModelProperty(value = "用户邮箱", required = false)
    private String     account;
    
    @ApiModelProperty(value = "标签id", required = false)
    private Long     tagId;

    private List<Long> appIds;
    
    /**用户id*/
    @ApiModelProperty(value = "mediaIds", required = false)
    private List<Long> mediaIds;
    
    /**用户类型*/
    @ApiModelProperty(value = "accountType", required = false)
    private Integer accountType;
   

    /**
     * Gets the app id.
     *
     * @return the app id
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * Sets the app id.
     *
     * @param appId the app id
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * Gets the app name.
     *
     * @return the app name
     */
    public String getAppName() {
        return appName;
    }

    /**
     * Sets the app name.
     *
     * @param appName the app name
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * Gets the platform.
     *
     * @return the platform
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * Sets the platform.
     *
     * @param platform the platform
     */
    public void setPlatform(String platform) {
        this.platform = platform;
    }

    /**
     * Gets the app ids.
     *
     * @return the app ids
     */
    public List<Long> getAppIds() {
        return appIds;
    }

    /**
     * Sets the app ids.
     *
     * @param appIds the app ids
     */
    public void setAppIds(List<Long> appIds) {
        this.appIds = appIds;
    }
    
    public Integer getExportType() {
		return exportType;
	}

	public void setExportType(Integer exportType) {
		this.exportType = exportType;
	}

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }
    
    public Long getTagId() {
		return tagId;
	}

	public void setTagId(Long tagId) {
		this.tagId = tagId;
	}
    
	public List<Long> getMediaIds() {
	     return mediaIds;
	 }

	    
	public void setMediaIds(List<Long> mediaIds) {
	    this.mediaIds = mediaIds;
	}
	
	
	public Integer getAccountType() {
	     return accountType;
	}

	    
    public void setAccountType(Integer accountType) {
	      this.accountType = accountType;
	 }
    
    /**
     * To string.
     *
     * @return the string
     */
    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}

==> ssp-center-api-0.2.39-gy-20180420.090923-3-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqAppStatistics.java <==
/**
 * Project Name:media-manager-biz<br>
 * File Name:ReqAppStatistics.java<br>
 * Package Name:cn.com.duiba.tuia.media.manager.model.req<br>
 * Date:2016年12月21日上午10:53:48<br>
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.<br>
 */
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.util.List;

import org.apache.commons.lang3.builder.ToStringBuilder;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

/**
 * ClassName: ReqAppStatistics <br/>
 * Function: 媒体数据请求对象. <br/>
 * date: 2016年12月21日 上午10:53:48 <br/>
 *
 * @author xiawei
 * @version
 * @since JDK 1.6
 */
@ApiModel
public class ReqAppStatistics extends ReqDateQuery{
 
    /**序列号*/
    private static final long serialVersionUID = 2154402586515939055L;

    /** 媒体ID. */
    @ApiModelProperty(value = "媒体ID", required = false)
    private Long       appId;

    /** 媒体名称. */
    @ApiModelProperty(value = "媒体名称", required = false)
    private String     appName;

    /** 系统平台. */
    @ApiModelProperty(value = "系统平台", required = false)
    private String     platform;
    
    /** 导出方式. */
    @ApiModelProperty(value = "导出方式", required = false)
    private Integer     exportType;//0是汇总，1是分日导出

    /** 用户ID. */
    @ApiModelProperty(value = "用户ID", required = false)
    private Long     mediaId;

    /** 用户邮箱. */
    @ApiModelProperty(value = "用户邮箱", required = false)
    private String     account;
    
    @ApiModelProperty(value = "标签id", required = false)
    private Long     tagId;

    private List<Long> appIds;
    
    /**用户id*/
    @ApiModelProperty(value = "mediaIds", required = false)
    private List<Long> mediaIds;
    
    /**用户类型*/
    @ApiModelProperty(value = "accountType", required = false)
    private Integer accountType;
    
    /**查询区间*/
    @ApiModelProperty(value = "查询区间类型", required = false)
    private List<Integer> selectRangeType; 
    

    /**
     * Gets the app id.
     *
     * @return the app id
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * Sets the app id.
     *
     * @param appId the app id
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    /**
     * Gets the app name.
     *
     * @return the app name
     */
    public String getAppName() {
        return appName;
    }

    /**
     * Sets the app name.
     *
     * @param appName the app name
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * Gets the platform.
     *
     * @return the platform
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * Sets the platform.
     *
     * @param platform the platform
     */
    public void setPlatform(String platform) {
        this.platform = platform;
    }

    /**
     * Gets the app ids.
     *
     * @return the app ids
     */
    public List<Long> getAppIds() {
        return appIds;
    }

    /**
     * Sets the app ids.
     *
     * @param appIds the app ids
     */
    public void setAppIds(List<Long> appIds) {
        this.appIds = appIds;
    }
    
    public Integer getExportType() {
		return exportType;
	}

	public void setExportType(Integer exportType) {
		this.exportType = exportType;
	}

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }
    
    public Long getTagId() {
		return tagId;
	}

	public void setTagId(Long tagId) {
		this.tagId = tagId;
	}
    
	public List<Long> getMediaIds() {
	     return mediaIds;
	 }

	    
	public void setMediaIds(List<Long> mediaIds) {
	    this.mediaIds = mediaIds;
	}
	
	
	public Integer getAccountType() {
	     return accountType;
	}

	    
    public void setAccountType(Integer accountType) {
	      this.accountType = accountType;
	 }
     
    public List<Integer> getSelectRangeType() {
        return selectRangeType;
    }

    
    public void setSelectRangeType(List<Integer> selectRangeType) {
        this.selectRangeType = selectRangeType;
    }
    /**
     * To string.
     *
     * @return the string
     */
    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

}
